@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 
 try:
-    from trytond.modules.account_payment_clearing.tests.test_account_payment_clearing import suite
+    from trytond.modules.account_payment_clearing.tests.test_account_payment_clearing import suite  # noqa: E501
 except ImportError:
     from .test_account_payment_clearing import suite
 
